'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactRedux = require('react-redux');
var Modal = _interopDefault(require('react-modal'));

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

var OPEN_DIALOG = 'OPEN_DIALOG';
var CLOSE_DIALOG = 'CLOSE_DIALOG';
var CLOSE_ALL_DIALOGS = 'CLOSE_ALL_DIALOGS';

function openDialog(name, payload) {
  return {
    type: OPEN_DIALOG,
    name: name,
    payload: payload
  };
}
function closeDialog(name) {
  return {
    type: CLOSE_DIALOG,
    name: name
  };
}
function closeAllDialogs() {
  return {
    type: CLOSE_ALL_DIALOGS
  };
}

var reduxDialog = function reduxDialog(dialogProps) {
  var name = dialogProps.name,
      _dialogProps$onAfterO = dialogProps.onAfterOpen,
      _dialogProps$onReques = dialogProps.onRequestClose;
  return function (WrappedComponent) {
    var ReduxDialog =
    /*#__PURE__*/
    function (_Component) {
      _inherits(ReduxDialog, _Component);

      function ReduxDialog() {
        _classCallCheck(this, ReduxDialog);

        return _possibleConstructorReturn(this, _getPrototypeOf(ReduxDialog).apply(this, arguments));
      }

      _createClass(ReduxDialog, [{
        key: "render",
        value: function render() {
          return React__default.createElement(Modal, _extends({
            contentLabel: name
          }, dialogProps, this.props), React__default.createElement(WrappedComponent, this.props));
        }
      }]);

      return ReduxDialog;
    }(React.Component);

    var mapStateToProps = function mapStateToProps(state) {
      var reducer = typeof state.get === 'function' ? state.get('dialogReducer') : state.dialogReducer;

      if (reducer.dialogs && reducer.dialogs.hasOwnProperty(name)) {
        var _reducer$dialogs$name = reducer.dialogs[name],
            isOpen = _reducer$dialogs$name.isOpen,
            payload = _reducer$dialogs$name.payload;
        return {
          isOpen: isOpen,
          payload: payload
        };
      }

      return {
        payload: {}
      };
    };

    var mapDispatchToProps = function mapDispatchToProps(dispatch, props) {
      return {
        onRequestClose: function onRequestClose() {
          props.onRequestClose && props.onRequestClose();
          dispatch(closeDialog(name));
        }
      };
    };

    return reactRedux.connect(mapStateToProps, mapDispatchToProps)(ReduxDialog);
  };
};

var initialState = {
  dialogs: {}
};
var reducer = (function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case OPEN_DIALOG:
      var dialogsAfterOpen = _extends({}, state.dialogs, _defineProperty({}, action.name, {
        isOpen: true,
        payload: action.payload
      }));

      return _extends({}, state, {
        dialogs: dialogsAfterOpen
      });
      break;

    case CLOSE_DIALOG:
      var dialogsAfterClose = _extends({}, state.dialogs, _defineProperty({}, action.name, {
        isOpen: false
      }));

      return _extends({}, state, {
        dialogs: dialogsAfterClose
      });
      break;

    default:
      return state;
  }
});

exports.default = reduxDialog;
exports.dialogReducer = reducer;
exports.openDialog = openDialog;
exports.closeDialog = closeDialog;
exports.closeAllDialogs = closeAllDialogs;
